%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% centerVals(m,varargin)
% 
%   The jth element of funs is u_j(q_0) where the u_j are the normalized
%   0-series eigenfunction on V_m. Additional argument are passed to
%   sequences, and the output of sequences are additional outputs.
% 
%   You MUST have run rPoly(n,'save') before using this program.
%
%   See also pointVals, path2val, path2norm, path2center.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [funs eigvals paths words mults] = centerVals(m);
% we need our paths, but only 0-series
[paths words eigvals mults] = sequences(m,'0-series','fractal','quiet');

% we don't actually use the first entries
paths = paths(2:m+1,:);

% center point values, as in path2center
b = paths.*(6*paths-8)+2;
d = 2/3-paths;
num = 3*d+b;
den = polyval([-36 60 -29 4],paths);
funs = (num./den);

% L_2 norms of our functions of function
n = normFactor(paths);
funs = funs./sqrt(n);
funs = prod(funs,1);
