%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% decimate(f,lambda,m)
% 
%   Given an eigenfunction f on V_{m-1} with eigenvalue R(lambda), use the
%   spectral decimation algorithm to extend f to an eigenfunction on V_m
%   with eigenvalue lambda.
% 
%   The array f needs to be big enough to accomodate these new points,
%   i.e. we need 
% 
%     length(f) >= 3*5^m+1.
% 
%   See also yMatrix, path2fun.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = decimate(f,lambda,m)

% if we weren't given m, pick the biggest one
if nargin == 2
  m = len2level(length(f))+1;
end

% we need this global variable to be defined
global masterInv
inv = masterInv{m+1};

% construct the matrix we'll use to go to the next level
Y = yMatrix(lambda);

% for each m-cell (represented by the prefix shared by the base 5
% representations of all of its points)
cells = 0:5^(m-1)-1;

% get boundary points by appending 11, 22, 33, 44 (in base 5) to the
% cell address
boundary = [f(inv(25*cells+6))
	    f(inv(25*cells+12))
	    f(inv(25*cells+18))
	    f(inv(25*cells+24))];

% The values we'll be filling appear consecutively in makeList(m). Since
% the first has base 5 (cell address)12
start = inv(25*cells+7)';

% we can just take that number + 1,2,...,11 to get all of the indices to
% change
target = [start;  start+1; start+2;  start+3;
	  start+4; start+5; start+6;  start+7;
	  start+8; start+9; start+10; start+11];

% we get our new values by applying Y to our old values
f(target) = Y * boundary;
answer = f;
