%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% decimateN(f,lambda,n)
% 
%   Extend the function f on VS_n to one higher level graph approximation. Note
%   that each time we do this we're increasing the length of f. This is
%   different from the regular decimate function in that it only considers
%   values on the diagonal (otherwise we'd need to come up with a general
%   labeling system for any n, which would be a huge pain).
% 
%   You MUST have run rPoly(n,'save') before using this program.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
function answer = decimateN(f, lambda)

% get which level we're dealing with
global rPoly_n
n = rPoly_n;

% these are the matrices we need, same definitions as in
% Zhou's paper
X = xMatrix(n);
J = jMatrix(n);
M = -diag(diag(X));

% this is the matrix that we use to get from V_0 to V_1\V_0
Y = -inv(X + lambda * M) * J;
   
% since we only want some of the point,
% we only need some of the rows of Y
step = 3*(n-1);
% we want points on cells along the diagonal
rows = [4*step:-1:3*step+1, 1, 2*step+1, step+1:2*step];
% but on each square we know that the two vertices off the 
% diagonal are the same
rows = rows(mod(1:2*step+2,3)~=2);
Y = Y(rows,:);
% along those lines, we'll only be inputing three of the 
% vertices on V_0, so we'll have to add columns of V
temp = Y(:,[4 1 2]);
temp(:,2) = temp(:,2) + Y(:,3);
% now decimation doesn't change the vertices we already knew
% so make Y act as the identity on those
Y = temp;
Y = [1 0 0; Y; 0 0 1];
% now given our previous values, we need to split them up
% in to diagonal values x and off diagonal values y
on_diag = mod(1:length(f),2)==1;
x = f(on_diag);
y = f(~on_diag);
len = length(x);
% and then arrange g so that each column contains the values
% for a 0-cell
g = [x(1:len-1); y; x(2:len)];
% now we apply our matrix Y
g = Y*g;
% and if this isn't the first time we've done this
if length(f) > 3
  % we take off the first row, since it's the same
  % as the last row of previous columns
  g = g(2:size(g,1),:);
  % stretch our matrix back into a 1d array
  g = reshape(g,1,[]);
  % and then add on 1, which we killed accidentally two steps ago
  g = [1 g];
else
  % if this is our first time, we don't need any fancy business
  g = reshape(g,1,[]);
end
% we're done!
answer = g;

