%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% eigenfunctions(m,varargin)
% 
%   Calls sequences and then constructs the corresponding eigenfunctions
%   (see sequences for the input syntax) optionally returns rest of the
%   output of sequences, STARTING WITH THE EIGENVALUES. Unless given the
%   'non-normalized' flag, will return normalized eigenfunctions.
% 
%   You MUST have run rPoly(n,'save') before using this program.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [funs eigvals paths words mults] = eigenfunctions(m,varargin)

[paths words eigvals mults] = sequences(m,varargin{:});

% the number of paths we have
len = size(paths,2);

% each row of functions is the eigenfunction corresponding
% to a column of p
funs = zeros(len,3*5^m+1);
for j = 1:len
  funs(j,:) = path2fun(paths(:,j));
end

% if we've been asked to, normalize these functions
if ~ismember('non-normalized',varargin)
  for j = 1:len
    f = funs(j,:);
    funs(j,:) = f/sqrt(norm2(f,m));
  end
end

