%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% normFactor(lambda)
% 
%   Return a factor alpha such that any eigenfunction f on V_m and its
%   extension g with eigenvalue lambda to V_{m+1} are related by
% 
%     (L_2 norm of g)^2/(L_2 norm of f)^2 = alpha.
% 
%   This should agree with norm2 in that
% 
%     norm2(g,m+1)/norm2(g,m) == alpha.
%
%   See also norm2, path2norm, integrate, innerProduct.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function factor = normFactor(lambda)

% see the README for a derivation of this formula
num = 20+lambda.*(-143+lambda.*(240-108.*lambda));
den = 4+lambda.*(-29+lambda.*(60-36.*lambda));

% the factor of 5 comes in because, when you weight by degree, there are
% 5 times as many points in V_{m+1} as in V_m.
factor = num./(5*den);
