%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path2center(path)
% 
%   Same as path2val(path,1), but 
%   
%     1. Give the NORMALIZED function value.
%     2. Faster, since it takes advantage of some more explicit formulas
%        that we have for this case.
%   
%   Note: this is only valid for 0-series eigenfunctions.
% 
%   See also path2val.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = path2center(path)

% we don't need the first step in the path
p = path(2:length(path));

% the elements of yMatrix(lambda) that we'll need
b = polyval([6 -8 2],p);
d = 2/3-p;

% summed appropriately
num = 3*d+b;

% and normalized (since we want NORMALIZED eigenfunctions)
den = polyval([-36 60 -29 4],p);

answer = prod(num./den);
