%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path2fun(path)
% path2fun(path,vals)
% 
%   Given path a column of paths(m), return the corresponding function
%   generated by the spectral decimation algorithm.  I.e. return a
%   function u on V_m such that 
% 
%     - (Delta_k) f == path(k) f.
% 
%   Note that path2fun can easily figure out what m is by looking at the
%   length of path. If given vals, use them as initial values on V_0.
% 
%   See also decimate, path2val, path2norm, path2center, eigenvalues, 
%            eigenfunctions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function f = path2fun(path,vals)

% if we just got one function
if min(size(path))==1
  % this is the m that was used in the call to paths
  m = length(path)-1;

  % this is how big f will have to be
  f = zeros(1,3*5^m+1);

  % based on path(1), we have different initial values for f
  if path(1) == 0
    f(1:4) = [1 1 1 1];
  else
    f(1:4) = [1 -1 1 -1];
  end

  % if we got initial values, use them instead
  if nargin == 2
    f(1:4) = vals;
  end

  % now for each remaining level
  for k=2:length(path)
    % we extend f using decimate
    f = decimate(f,path(k),k-1);
  end

% otherwise each column of path is a path
else 
  m = size(path,1)-1;
  len = size(path,2);     % number of paths
  f = zeros(len,3*5^m+1);
  % run path2fun on each column
  for j = 1:len
    p = path(:,j);
		f = path2fun(p);
    f(j,:) = f./sqrt(norm2(f)); % BADNESS BADNESS BADNESS
  end
end


