%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path2norm(path)
% 
%   Given path a sequence of eigenvalues describing an eigenfunction
%   function u on V_m, return the square of the L_2 norm of u. More
%   precisely, return 
%   
%     (L_2 norm of u)^2 / (L_2 norm of u restricted to V_0)^2.
% 
%   This norm should agree with the one provided by norm2, which, since
%   path2fun starts with |u|=1 on V_0, means
%     
%     4*path2norm(path) == norm2(path2fun(path),m).
% 
%   Of course path2norm is MUCH faster than using path2fun and then norm2,
%   since it doesn't require computing the entire function.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = path2norm(path)

% we don't care about the initial eigenvalue
p = path(2:length(path));

% Each time we extend from lambda_m to lambda_{m+1}, our square norm
% gets multiplied by normFactor(lambda_{m+1}).
n = normFactor(p);
answer = prod(n);

