%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path2val(path,x)
% 
%   Given x the base 5 representation of a point in V_m and path the
%   sequence of eigenvalues describing an eigenfunction f on V_m, return
%   the value of f at the point x. When you only care about a specific
%   point, this is MUCH MUCH faster than constructing all of f.
%
%   Should have
%     
%     path2val(path,x) == path2fun(path)(inv(x))
% 
%   Note: this currently only works for 0-series eigenfunctions.
%   Note: the function value is NOT NORMALIZED, use path2norm for that.
%
%   See also path2fun, decimate, path2center.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = path2val(path,x)

% this is the level of the function we're considering
m = length(path)-1;

% the values of f on V_0
f = [1; 1; 1; 1];

% the digits of our representation x
digits = num2array(x,m+1);

% Given a number j=0,1,...,4 corresponding a 0-cells in V_1, A(j+1,:)
% contains the list indices of the points in that 0-cell.
A = [6  10 11 15
     1  5  6  7
     8  2  9  10
     11 12 3  13
     14 15 16 4 ];

% for each level
for j=1:m;
  lambda = path(j+1);
  % contruct the matrix to extend a 0-cell in V_{m-1} to a 1-cell in V_m
  Y = yMatrixFull(lambda);
  % but only look at the values on the 0-cell in V_m that contains x 
  digit = digits(j);
  rows = A(digit+1,:);
  Y = Y(rows,:);
  f = Y*f;
end

% finally, the last digit in x tells us which of these 4 points we're
% interested in.
answer = f(digits(m+1));
