%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% pointVals(x,m)
% 
%   Given x the base 5 representation of a point in V_m, return the array
%   whose jth element is 
%    
%     u_j(x) * u_j(q_0)
% 
%   where the u_j are the normalized 0-series eigenfunctions on V_m.
%   Optionally return output of sequences.
%   
%   You MUST have run rPoly(n,'save') before using this program.
% 
%   See also path2val, path2norm, path2center, centerVals, sequences
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [funs eigvals paths words mults] = pointVals(x,m)

% we need our paths, but only 0-series
[paths words eigvals mults] = sequences(m,'0-series','fractal');

len = length(eigvals);

for j = 1:len             % for each eigenfunction
  path = paths(:,j);      % get its path
  f = path2val(path,x);   % its value at x
  n = path2norm(path);    % its L_2 norm
  c = path2center(path);  % and its value at q_0
  funs(j) = f*c/n;        % put these together
end
