%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% yMatrix(lambda)
% 
%   Return the Y matrix described in the README. Briefly, when extending
%   an eigenfunction f from V_m to and eigenfunction g on V_{m+1} with
%   eigenvalue lambda, we have
% 
%     [g on 1 cell] == [f on boundary;
%                       Y*(f on boundary)].
%
%   See the README for a derivation of this formula for Y.
% 		      
%   See also yMatrixFull, decimate, jMatrix, xMatrix.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Y = yMatrix(lambda)

g = 1/polyval([36 -60 +29 -4],lambda);
a = polyval([12 -14 3],lambda);
b = polyval([6 -8 2],lambda);
c = 1/3;
d = 2/3-lambda;

Y = zeros(12, 4);
Y(:,1) = [a b a c c d d c c c d c];
Y(:,2) = [c d c a a b d c c c d c];
Y(:,3) = [c d c c c d b a a c d c];
Y(:,4) = [c d c c c d d c c a b a];
Y = -g*Y;
