%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% yMatrixFull(lambda)
% 
%   Like yMatrix, but returns a 16x4 matrix so that instead of
% 
%     [g on 1 cell] == [f on boundary;
%                       yMatrix(lambda)*(f on boundary)].
% 
%   we have
% 
%     [g on 1 cell] == [yMatrixFull(lambda)*(f on boundary)].
% 
%   See also yMatrix, decimate, jMatrix, xMatrix.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Y = yMatrixFull(lambda)

% exactly the same as yMatrix(lambda)
const = 1/(lambda*(lambda*(36*lambda-60)+29)-4);
a = 3+lambda*(-14+12*lambda);
b = lambda*(6*lambda-8)+2;
c = 1/3;
d = 2/3-lambda;

% but add in some zeros in the first four rows
Y = zeros(16, 4);
Y(:,1) = [0 0 0 0 a b a c c d d c c c d c];
Y(:,2) = [0 0 0 0 c d c a a b d c c c d c];
Y(:,3) = [0 0 0 0 c d c c c d b a a c d c];
Y(:,4) = [0 0 0 0 c d c c c d d c c a b a];
Y = -const*Y;

% and then stick in a copy of the identity
Y(1:4,:) = diag([1 1 1 1])
