%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% chebyshevT(n)
% 
%   Return an array of coefficients such that
%     
%     polyval(chebyshevT(n),x) == T_n(3*x-1)
% 
%   where T_n is the nth Chebyshev polynomial of the first kind.
%
%   See also chebyshevU, continueEigval.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = chebyshevT(n)

% the zeroth degree polynomial is just 1
if n == 0
  answer = 1;
  return;
end

% otherwise, we use the recurrence T_{n+1} = 2x * T_n - T_{n-1}
% actually, a different recurrence that works with 3x-1
last = [1];
answer = [3 -1];
for j = 2:n
  temp = answer;
  answer = 6*[answer 0] - 2*[0 answer]-[0 0 last];
  last = temp;
end
