%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% chebyshevU(n)
% 
%   Return an array of coefficients such that
%     
%     polyval(chebyshevU(n),x) == U_n(x)
% 
%   where U_n is the nth Chebyshev polynomial of the second kind.
%
%   See also chebyshevT, continueEigval.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = chebyshevU(n)

% the zeroth degree polynomial is just 1
if n == 0
  answer = [1];
  return;
end

% otherwise, we use the recurrence U_{n+1} = 2x * U_n - U_{n-1}
% actually, a different recurrence that works with 3x-1
last = [1];
answer = 2*[3 -1];
for j = 2:n
  temp = answer;
  answer = 6*[answer 0] - 2*[0 answer]-[0 0 last];
  last = temp;
end
