%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% continueEigval(y)
% 
%   Return a sorted array with the solutions to 
% 
%     R(x) = y
% 
%   where R(x) is the spectral decimation function on VS_n. 
% 
%   You MUST have run rPoly(n,'save') before using this program.
% 
%   See also sequences
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = continueEigval(y,j)
global rPoly_r;              % get the coefficients of R(x)
p            = rPoly_r;
p(length(p)) = -y;           % and the coefficients for R(x)-x
answer       = roots(p);     % find the roots of R(x) - x
answer       = sort(answer); % and sort them
if nargin == 2
  answer = answer(j);
end

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is an alternate implementation using linear interpolation. While
% faster, this is harder to trust, so we're not using it, for now.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global rPoly_x rPoly_y rPoly_deg
if nargin == 1
  answer = zeros(1,rPoly_deg-1);
  lambda = y;
  for j = 1:rPoly_deg-1
    answer(j) = interp1q(rPoly_x{j},rPoly_y{j},lambda);
  end
else
  lambda = y;
  answer = interp1q(rPoly_x{j},rPoly_y{j},lambda);
end

function answer = interp1q(x,y,z)
len = length(x)
index = floor(3/4*len*z);
index = max(index,1);
index = min(index,len-1);
slope = (y(index+1)-y(index))/(x(index+1)-x(index));
answer = y(index) + slope * (z-x(index));
