%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% rPoly(n)
% 
%  Computes the polynomials in Zhou's paper, as well as forbidden eigenvalues,
%  and if passed the 'save' flag, saves them as global variables. Since these
%  global variables are used blindly by many programs, be careful when running
%  this without this flag.
% 
% 
%   See also chebyshevU, chebyshevT, smallN.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [r,rho,bad,f,g,h] = rPoly(n,varargin)

f   = chebyshevT(n)-3*[0 chebyshevT(n-1)];
g   = [0 chebyshevU(n-1)]-[0 0 chebyshevU(n-2)];
h   = [0 chebyshevU(n-1)]-3*[0 0 chebyshevU(n-2)];
r   = [conv(g,h) 0];
r   = r(find(r ~= 0, 1):length(r));
rho = (4*n-3)*(2*n-1);

bad = [4/3];
bad = union(bad,roots(f));
bad = union(bad,roots(g));

interp_len = 10000;
lower = sort(roots(r));
upper = sort(roots(r - [zeros(1,length(r)-1) 4/3]));
x = {};
y = {};
for j = 1:length(r)-1
  y{j} = linspace(lower(j),upper(j),interp_len);
  x{j} = polyval(r,y{j});
end

if ismember('save',varargin)
  global rPoly_f 
  global rPoly_g 
  global rPoly_h 
  global rPoly_r 
  global rPoly_rho 
  global rPoly_bad 
  global rPoly_n
  global rPoly_x
  global rPoly_y
  global rPoly_deg
  rPoly_f   = f;
  rPoly_g   = g;
  rPoly_h   = h;
  rPoly_r   = r;
  rPoly_n   = n;
  rPoly_rho = rho;
  rPoly_bad = bad;
  rPoly_x   = x;
  rPoly_y   = y;
  rPoly_deg = length(r);
end


