%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% word2eigval(word)
% 
% 	Return the (graph) eigenvalue associated with word. If given the
% 	'fractal' flag, return the fractal eigenvalue. Note that the fractal
% 	flag doesn't work for multiple inputs.
% 
%   You MUST have run rPoly(n,'save') before using this program.
% 
% 	See also word2path, word2fun, eigenvalues.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function eigval = word2eigval(word,varargin)

if min(size(word)) == 1
  % we just got one word
  path = word2path(word);
  m = length(word)-1;
  eigval = path(m+1);
else
  % we got an array of words
  path = word2path(word);
  m = size(path,1);
  eigval = path(m,:);
end

if ismember('fractal',varargin)
  global rPoly_rho
  rho     = rPoly_rho;
  temp    = small(eigval);             % apply small
  error   = max(abs(rho*temp-eigval)); % measure of the error
  counter = 1;                         % intialize counter
  % we keep continuing with lowest inverse until either
  % 1) things are converging pretty well
  % 2) things screw up because of rounding error
  while 1
  eigval = small(temp);          % apply small
  err    = abs(temp-rho*eigval); % redefine error
  if err < 1e-15 || err > 1      % condition on error
    break;
  end
  counter = counter + 1;          % increment counter
  swap    = temp;                 % swap temp and eigval
    temp    = eigval;
    eigval = swap;
  end
  eigval = rho^(m+counter)*temp';
end
