%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% initialize(m)
% initialize(m,'save')
% 
%   Create the global cell arrays
% 
%     masterList
%     masterInv
%     masterDups
%     masterX
%     masterY
% 
%   such that, for j <= m, the assignments
% 
%     list    = masterList{j+1}
%     inv     = masterInv{j+1}
%     dups    = masterDups{j+1}
%     X       = masterX{j+1}
%     Y       = masterY{j+1}
%     degrees = masterDegrees{j+1}
% 
%   are equivalent to (but faster than)
% 
%     list = makeList(j)
%     [inv dups] = invertList(j)
%     [X Y] = location(list,j)
%     degrees = ((dups(list)~=0)+1)'
% 
%   initialize will also run rPoly(2,'save'), which should make all VS_n
%   specific programs default to n=2.
%
%   initialize(m,'save') will, in addition, write these variables to
%   the the file "listData.mat" (to load these variables into a new MATLAB
%   session simply type
% 
%     load 'listData'
%     
%   (no global declarations necessary). 
% 
%   See also makeList, invertList, location.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function intitialize(m,filename)

global masterList;
global masterInv;
global masterDups;
global masterX;
global masterY;
global masterDegrees;

masterList = {};
masterInv  = {};
masterDups = {};
masterX = {};
masterY = {};
masterDegrees = {};

for j = 0:m

  tic;
  fprintf('level: %d \n', j)

  % use lists to construct list,inv,dups
  list = makeList(j);
  [inv,dups]=invertList(list,j);
  masterList{j+1} = list;
  masterInv{j+1} = inv;
  masterDups{j+1} = dups;
  
  % construct list of X and Y locations
  len = length(list);

  % use location to take our list of points to X and Y
  [X,Y] = location(list,j);
  masterX{j+1} = X;
  masterY{j+1} = Y;

  % use list and dups to greate degrees
  degrees = ((dups(list)~=0)+1)';
  masterDegrees{j+1} = degrees;

  toc;

end  

% if neccessary, save data to a file
if nargin > 1
  save listData masterList ...
                masterInv ...
                masterDups ... 
                masterX ... 
                masterY ... 
                masterDegrees
end

% set n=2 as the default
rPoly(2,'save');
