%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% location(x,m)
% 
%   Given a list of base 5 representations of points in V_m, return two
%   arrays X and Y such that, for each j, [X(j) Y(j)] is the position of
%   the point represented by x(j). This is mainly useful for plotting
%   functions on V_m.
%
%   See also makeList, initialize.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [X,Y] = location(x, m)

% first contruct array of digits base 5
len = length(x);
digits = zeros(len,m+1);
temp = x;
five = uint32(5);
for j=0:m
  digits(:,m+1-j) = mod(temp,5);
  temp = floor(double(temp)/5);
%   temp = idivide(temp,5);
end

% locations of the boundary points
directions = [0 0; -1 1; 1 1; 1 -1; -1 -1];

len = length(x);

% different digits have different geometric importance, as explained in
% the README. This array will be multiplied element-wise by digits, so
% each row is the same.
scaling = zeros(len,m+1);
scaling(1,:) = [3.^(-[1:m]) 1/2*1/3^m];
for k=2:len
  scaling(k,:) = scaling(1,:);
end

% now let x and y be arrays such that x(j) is the x location of the boundary
% point q_j and similarly for y.
x = directions(:,1);
y = directions(:,2);

% for each digit of each vertex, we record the movement in the correct
% direction, then scale this by our scaling array, and sum
X = sum(x(digits+1).*scaling,2);
Y = sum(y(digits+1).*scaling,2);

