%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% neighbors(x)
% 
%   Given the base 5 representation x of a point in V_m, return base 5
%   representations of the points adjacent to x in V_m. 
%
%   See also makeList, invertList.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function buddies = neighbors(x,m)

global masterDups;
dups = masterDups{m+1};

% Note that: 
%   1. A vertex has 3 neighbors if and only if it has no duplicate names.
%   2. We get duplicate names by changing the last digit of a base 5 
%      representation. If we do this for all names of a vertex, we'll
%      get all of the neighbors.

if dups(x) == 0
  % this vertex has 3 neighbors
  last    = mod(x,5);                % last digit
  temp    = uint32([1 2 3 4]);       % list of digits 1-4
  temp    = temp(find(temp~=last));  % don't want last digit in this list
  buddies = x-last+temp;
else
  % this vertex has 6 neighbors
  % repeat the above program, but for both names of x.
  y       = dups(x);
  lastx   = mod(x,5);
  lasty   = mod(y,5);
  temp    = uint32([1 2 3 4]);
  tempx   = temp(find(temp ~= lastx));
  tempy   = temp(find(temp ~= lasty));
  buddies = [x-lastx+tempx, y-lasty+tempy];
end

