%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotArray(fun,array,nCols,nRows)
% 
%   Run fun on each row of array. Arrange the plots that are generated on
%   figures with a grid of plots with nCols columns and nRows rows. Use
%   this in conjunction with the plotChoice and plotChoiceDiag methods so 
%   that you get nice titles. This could be extended to pass other arguments
%   to fun and other fancy stuff but I don't think we need it.
% 
%   See also plotWord, plotWordDiag
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
function plotArray(fun,array,nCols,nRows,filename,varargin);

nPlots = nCols*nRows;  % number of plots per figure
len = size(array,1);   % number of rows in array

% if we got a filename
if nargin == 5
  save_plots = 1;
else
  save_plots = 0;
end

pages = floor((len-1)/nPlots)+1;
for page = 1:pages
  figure;
  set(gcf,'PaperPositionMode','auto');
  set(gcf,'Position',[1,1,700,900]);
  if page == pages
    last_plot = mod(len-1,nPlots)+1;
  else
    last_plot = nPlots;
  end
  for j=1:last_plot
    subplot(nCols,nRows,j);
    index = (page-1)*nPlots+j;
    input = array(index,:);
    fun(input,'subplot',varargin{:});
  end
  if save_plots
    saveas(gcf,[filename dec2base(page,10,2) '.pdf']);
    close;
  end
end
