%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% weyl_limits(m,n)
% 
%   Find (quickly) the maximum minimum values of the weyl ratios.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function answer = weyl_limits(m,n_range)

answer = zeros(length(n_range),2);

for k = 1:length(n_range)
  n = n_range(k);
  [r rho] = rPoly(n,'save');
  max_index = length(r)-1;

  set_size = (3*(4*n-3)^m + 1); % number of points on level m

  % use recurrence to get number of things born with 4/3
  % should just solve this, but am lazy
  four_thirds = 3;
  for j = 1:m
    four_thirds = (4*n-3)*four_thirds - (4*n-4);
  end

  % now let's find the biggest eigenvalue not 4/3
  second_biggest = word2eigval([0 max_index*ones(1,m)]);
  eigvals = [second_biggest 4/3]';

  len     = length(eigvals);
  temp    = small(eigvals);               % apply small
  err     = max(abs(rho*temp-eigvals));   % measure of the error
  counter = 1;                            % intialize counter
  while 1
    eigvals = small(temp);                % apply small
    err     = max(abs(temp-rho*eigvals)); % redefine error
    if err < 1e-15 || err > 1             % condition on error
      break;
    end
    counter = counter + 1;                % increment counter
    swap    = temp;                       % swap temp and eigvals
    temp    = eigvals;
    eigvals = swap;
  end
  eigvals = rho^(m+counter)*temp';

  % pull out the values we want
  second_biggest = eigvals(1);
  biggest = eigvals(2);

  alpha = log(4*n-3)/log((4*n-3)*(2*n-1));

  max_weyl = set_size/biggest^alpha;
  min_weyl = (set_size-four_thirds)/biggest^alpha;

  answer(k,:) = [min_weyl max_weyl];
end
