%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ratioGap(n)
%
%  Find guaranteed gaps in ratios for VS_n
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function gaps = ratioGap(n)

% error bound
epsilon = 1e-8;

% find fixed point p
r = rPoly(n); % NOTE: we'll reassign the variable 'r' later on
len_r = length(r);
r_minus_x = r-[zeros(1,len_r-2) 1 0];
fixed = roots(r_minus_x);
p = max(fixed);

% scaling factor
rho = (4*n-3)*(2*n-1);

% now we need the ranges I_j = [r_j, s_j] of the inverse functions
a = continueEigvalN(0)';
b = continueEigvalN(p)';

% r = lower endpoints, s = upper endpoints
r = min(a,b);
s = max(a,b);

max_r = max(r)

% add in 4/3
r = [r 4/3];
s = [s 4/3];

% create all of the intervals I_{j,k}

lower = {}; % lower endpoints
upper = {}; % upper endpoints

for j = 2:2*n
  for k = 2:2*n
    lower{length(lower)+1} = smallLimitRatio(r(k),s(j),n);
    upper{length(upper)+1} = smallLimitRatio(s(k),r(j),n);
  end
end

lower = cell2mat(lower);
upper = cell2mat(upper);

% print out endpoints in readable format for debugging
% test = [lower; upper]';

max_upper = max(upper)
min_lower = min(lower)

% find power k_lower such that rho^-k_lower < min(lower)
% find power k_upper such that rho^k_upper > max(upper)
k_lower = ceil(-log(max(upper))/log(rho))
k_upper = floor(1-log(min(lower))/log(rho))

% add in rho^k * intervals for all allowable k
temp1 = lower;
temp2 = upper;
for k=k_lower:k_upper
  lower = [lower rho^k*temp1];
  upper = [upper rho^k*temp2];
end

gaps = intervalGap(lower,upper);

% discard any information outside the interval [1,R]
gaps = gaps(:,gaps(2,:) <= rho & gaps(1,:) >= 1);
