%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% smallLimitRatio(num,den,small_x,small_y)
% 
%   Approximate the limit of
% 
%     smallN^k(num)/smallN^k(den)
% 
%   as k goes to infinity. rPoly needs to have been run already. 
%   smallN is a piecewise linear function satisfying 
%    
%     f(small_x) = small_y.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = smallLimitRatio(num,den,small_x,small_y,interp_len)

global rPoly_rho
rho = rPoly_rho;

% when the error in the numerator and denominator
% are this low, we stop applying small
epsilon = 1e-5;

num1 = interp1q(small_x,small_y,num,interp_len);
den1 = interp1q(small_x,small_y,den,interp_len);

% while max( abs(num-rho*num1)/num, abs(den-rho*den1)/den ) > epsilon
while max( abs(num-rho*num1), abs(den-rho*den1) ) > epsilon
  % disp(max( abs(num-rho*num1)/num, abs(den-rho*den1)/den ) > epsilon)
  num  = num1;
  den  = den1;
  num1 = interp1q(small_x,small_y,num,interp_len);
  den1 = interp1q(small_x,small_y,den,interp_len);
end

answer =  num1/den1;

% this is faster than the builtin interp1q, which is ridiculous
% function answer = interp1q(x,y,z)
% if z == 0
%   answer = y(1);
%   return;
% end
% indices = find(x<z);
% index = indices(1);
% slope = (y(index+1)-y(index))/(x(index+1)-x(index));
% answer = y(index) + slope * (z-x(index));

function answer = interp1q(x,y,z,len)
index = floor(3/4*len*z);
index = max(index,1);
index = min(index,len-1);
% index = find(x>z,1);
slope = (y(index+1)-y(index))/(x(index+1)-x(index));
answer = y(index) + slope * (z-x(index));
