%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% slowNorms(m,lambda_0)
% 
%   Plot norm(f) vs. eigenvalue(f) for function f in the lambda_0-series
%   But do this in for loops, not with array operations. This should 
%   keep memory from being a problem at higher levels.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function slowNorms(m,lambda_0)

[paths words e] = sequences(m,lambda_0);
e= 15^m * e;
% not_redundant = find(words(m+1,:) ~= 1);
% paths = paths(:,not_redundant);
% words = words(:,not_redundant);
% e = e(:,not_redundant);
nFuns = size(paths,2);

sup_norm = zeros(1,nFuns);
L4_norm = zeros(1,nFuns);

hold on;
for j = 1:nFuns
  word = words(:,j);
  path = paths(:,j);
  f = word2fun(word)/sqrt(path2norm(path));
  sup_norm(j) = max(abs(f));
  L4_norm(j) = integrate(f.^4,m)^(1/4);
end
  
subplot(2,1,1);
plot(e,sup_norm,'.');
disp(min(sup_norm));
ylabel('sup norm');
xlabel('eigenvalue');
title(['level ' num2str(m) ', ' num2str(lambda_0,3) ' series']);
grid();

subplot(2,1,2);
plot(e,L4_norm,'.');
ylabel('L_4 norm');
xlabel('eigenvalue');
title(['level ' num2str(m) ', ' num2str(lambda_0,3) ' series']);
grid();

hold off;
