%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% distances(m)
% 
%   Return the shortest-path distance function on V_m (function in list
%   order).
% 
%   See also makeList, location, neighbors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = distances(m)
global masterList
global masterInv

list = masterList{m+1};
inv = masterInv{m+1};

answer = zeros(1,length(list));   % this is our array of distances
oldpoints = inv(1:4);             % points closest to center
answer(oldpoints)=[1 1 1 1];      % all have distance 1
newpoints = [];                   % points we've dealt with this round

% while there are still points without distances
while min(answer)==0
  % and for each point we just assigned a distance to
  for j=1:length(oldpoints)
    index = oldpoints(j);
    point = list(oldpoints(j));
    % look at its neighbors
    buddies = inv(neighbors(point,m));
    % who we haven't already assigned distances to
    buddies = buddies(answer(buddies)==0);
    % and give them 1+distance of point we're considering
    answer(buddies)=answer(index)+1;
    % finally, add these the the points we've dealt with this round
    newpoints = [newpoints; buddies];
  end
  % next time we'll loop over the points we just made
  oldpoints = newpoints;
  newpoints = [];
end
