%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% integrate(f,m)
% 
%   Return the integral of f thought of as function on V_m (points are
%   weighted by degree). If m is not specified, it uses the biggest one
%   possible.
% 
%   See also innerProduct, norm2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = integrate(f,m)


if min(size(f)) == 1           % we just got one function

  if nargin == 2               % if we know m
    g = f(1:3*5^m+1);          % only want f on V_m
    g = reshape(g,1,[]);       % want f to be a row vector
  else                         % if we don't know m
    m = len2level(length(f));  % figure out m
    g = reshape(f,1,[]);       % get a row vector
  end

  % we need to know degrees to weight the sum
  global masterDegrees
  degrees = masterDegrees{m+1};

  % the sum we want
  answer = sum(degrees.*g)/sum(degrees);

else                           % each row of f is a function
  if nargin == 1               % if we don't know m
    m = len2level(length(f));  % figure out m
  end

  % we need to know degrees to weight the sum
  global masterDegrees
  degrees = masterDegrees{m+1};

  d = repmat(degrees,size(f,1),1);    % need copies of degrees
  answer = sum(d.*f,2)./sum(degrees);
end
